package myexample.demo.controller;

import org.springframework.ai.openai.OpenAiChatClient;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.Map;

@RestController
@RequestMapping("/chat")
public class BasicChatController {

    private final OpenAiChatClient chatClient;

    @Autowired
    public BasicChatController(OpenAiChatClient chatClient) {
        this.chatClient = chatClient;
    }

    /**
     * Handles GET requests to the /greet endpoint.
     *
     * @param message the message to be sent to the OpenAI chat client. Defaults to "Tell a random good morning fact" if not provided.
     * @return a map containing the response generated by the OpenAI chat client.
     */
    // http://localhost:9090/chat/greet?message=Tell%20a%20random%20good%20morning%20fact
    // http://localhost:9090/chat/greet?message=Hello
    @GetMapping("/greet")
    public Map chat(@RequestParam(value = "message", defaultValue = "Tell a random good morning fact") String message) {
        System.out.println("Message: " + message);
        return Map.of("Generated by OpenAI", chatClient.call(message));
    }
}
